@@ -12,6 +12,7 @@ def api_exception_wrapper(func):
             return func(*args, **kwargs)
         except requests.exceptions.HTTPError as e:
             print(func.__name__, e.response.json())
+            exit(1)
 
     return wrapper
 
@@ -21,6 +22,19 @@ class APIClient:
         self.token = token
         self.base_url = base_url
 
+    def _get_deployment_volume_url(self, deployment_type, deployment_volume_id=None):
+        url = self.base_url
+        if deployment_type == 'service':
+            url += f'/operations/service-volumes/'
+        elif deployment_type == 'database':
+            url += f'/operations/database-volumes/'
+        else:
+            raise ValueError('Invalid deployment type')
+
+        if deployment_volume_id:
+            url += f'{deployment_volume_id}/'
+        return url
+
     @api_exception_wrapper
     def fetch_service(self, service_id):
         url = f'{BACKEND_URL}/operations/services/{service_id}/'
@@ -37,6 +51,33 @@ class APIClient:
         response.raise_for_status()
         return response.json()
 
+    @api_exception_wrapper
+    def fetch_volume(self, volume_id):
+        url = f'{BACKEND_URL}/operations/volumes/{volume_id}/'
+        headers = {'Authorization': f'Token {self.token}'}
+        response = requests.get(url, headers=headers)
+        response.raise_for_status()
+        return response.json()
+
+    @api_exception_wrapper
+    def fetch_deployment_volume(self, deployment_volume_id, deployment_type):
+        url = self._get_deployment_volume_url(deployment_type, deployment_volume_id)
+        headers = {'Authorization': f'Token {self.token}'}
+        response = requests.get(url, headers=headers)
+        response.raise_for_status()
+        return response.json()
+
+    @api_exception_wrapper
+    def patch_service(self, service_id, image_id):
+        url = f'{BACKEND_URL}/operations/services/{service_id}/'
+        headers = {'Authorization': f'Token {self.token}'}
+        data = {
+            'image_id': image_id
+        }
+        response = requests.patch(url, headers=headers, json=data)
+        response.raise_for_status()
+        return response.json()
+
     @api_exception_wrapper
     def create_image(self, tag, previous_image, base_image_id=None, branch=None):
         url = f'{BACKEND_URL}/operations/images/'
@@ -59,17 +100,6 @@ class APIClient:
         response.raise_for_status()
         return response.json()
 
-    @api_exception_wrapper
-    def patch_service(self, service_id, image_id):
-        url = f'{BACKEND_URL}/operations/services/{service_id}/'
-        headers = {'Authorization': f'Token {self.token}'}
-        data = {
-            'image_id': image_id
-        }
-        response = requests.patch(url, headers=headers, json=data)
-        response.raise_for_status()
-        return response.json()
-
     @api_exception_wrapper
     def create_service(self,
                        project_id,
@@ -127,6 +157,41 @@ class APIClient:
         response.raise_for_status()
         return response.json()
 
+    @api_exception_wrapper
+    def create_volume(self, project_id, name):
+        url = f'{BACKEND_URL}/operations/volumes/'
+        headers = {'Authorization': f'Token {self.token}'}
+        data = {
+            'project_id': project_id,
+            'name': name
+        }
+        response = requests.post(url, headers=headers, json=data)
+        response.raise_for_status()
+        return response.json()
+
+    @api_exception_wrapper
+    def create_deployment_volume(self, volume_id, deployment_id, mount_path, size, deployment_type):
+        url = self._get_deployment_volume_url(deployment_type)
+        headers = {'Authorization': f'Token {self.token}'}
+
+        data = {
+            'volume_id': volume_id,
+            f"{deployment_type}_id": deployment_id,
+            'target': mount_path,
+            'capacity': size
+        }
+        response = requests.post(url, headers=headers, json=data)
+        response.raise_for_status()
+        return response.json()
+
+    @api_exception_wrapper
+    def commit_image(self, image_id):
+        url = f'{BACKEND_URL}/operations/images/{image_id}/commit/'
+        headers = {'Authorization': f'Token {self.token}'}
+        response = requests.post(url, headers=headers)
+        response.raise_for_status()
+        return response.json()
+
     @api_exception_wrapper
     def list_services(self, project_id, type_id=None, search=None, limit=20, offset=0):
         url = f'{BACKEND_URL}/operations/services/'
@@ -168,3 +233,31 @@ class APIClient:
         response = requests.get(url, headers=headers, params=params)
         response.raise_for_status()
         return response.json()
+
+    @api_exception_wrapper
+    def list_volumes(self, project_id, search=None, limit=20, offset=0):
+        url = f'{BACKEND_URL}/operations/volumes/'
+        headers = {'Authorization': f'Token {self.token}'}
+        params = {
+            'project': project_id,
+            'search': search,
+            'limit': limit,
+            'offset': offset
+        }
+        response = requests.get(url, headers=headers, params=params)
+        response.raise_for_status()
+        return response.json()
+
+    @api_exception_wrapper
+    def list_deployment_volumes(self, deployment_id, deployment_type, search=None, limit=20, offset=0):
+        url = self._get_deployment_volume_url(deployment_type)
+        headers = {'Authorization': f'Token {self.token}'}
+        params = {
+            f"{deployment_type}": deployment_id,
+            'search': search,
+            'limit': limit,
+            'offset': offset
+        }
+        response = requests.get(url, headers=headers, params=params)
+        response.raise_for_status()
+        return response.json()
