@@ -12,6 +12,7 @@ Options:
 """
 import argparse
 import uuid
+from time import sleep
 
 import pkg_resources
 
@@ -46,6 +47,8 @@ create_parser.add_argument('--base_service_id', help='Base service ID to use for
 create_parser.add_argument('--test-domain', help='Test domain to use for service creation', required=False)
 create_parser.add_argument('--no-new-image', help='Do not create a new image', action='store_true', default=False)
 create_parser.add_argument('--no-deploy', help='Do not deploy service', action='store_true', default=False)
+create_parser.add_argument('--share-storage', help='Share storage with base service', action='store_true',
+                           default=False)
 
 token = None
 client = APIClient(token)
@@ -117,6 +120,33 @@ def handle_create(args):
         test_domain=test_domain
     )
     print(f"{service['name']} service has been created with ID {service['id']}")
+
+    if base_service['volumes']:
+        volume_relations = client.list_deployment_volumes(
+            base_service['id'], deployment_type='service'
+        )['results']
+
+        if args.share_storage is False:
+            print(f"Creating {len(volume_relations)} volumes")
+            sleep(1)
+            for volume_relation in volume_relations:
+                volume_relation['volume'] = client.create_volume(
+                    project_id=args.project_id,
+                    name=f"{args.service_name}-vol-{hex(uuid.uuid4().int)[:6]}",
+                )
+            print("Volumes created")
+
+        for volume_relation in volume_relations:
+            print(f"Attaching volume {volume_relation['volume']['name']} to {service['name']}")
+            client.create_deployment_volume(
+                volume_id=volume_relation['volume']['id'],
+                deployment_id=service['id'],
+                deployment_type='service',
+                mount_path=volume_relation['target'],
+                size=volume_relation['volume'].get('capacity', None)
+            )
+            print(f"Volume {volume_relation['volume']['name']} attached")
+
     if args.no_deploy is False:
         if image_id == base_service['image_id']:
             images = []
@@ -124,6 +154,9 @@ def handle_create(args):
             images = [image_id]
         client.create_pipeline(args.project_id, [service['id']], images)
         print(f"{service['name']} service begins to deploy")
+    elif args.no_deploy is True and args.no_new_image is False:
+        client.commit_image(image_id)
+        print(f"{service['name']} service image begins to create but no deploy is scheduled")
 
 
 handlers = {
